@@ -35,7 +35,7 @@ logger = get_logger(eval(properties.log_types))
 # obj.exe_sql("findGoodsList")
 
 批量语句执行DEMO:
-# obj=getDbObj(path=project_path +'/mysql/test.xml',debug=True)
+# obj=getDbObj(path=project_path +'/mysql/mysql.xml',debug=True)
 # obj.exe_sql_obj_queue(queue_obj={"test":(1,2),"test":(2,3)})
 或者
 # obj.exe_sql_queue(method_queue=['test','test','test_s','test','test'],args_queue=[('1','2'),('2','3'),(),('3','4'),('3','4')])
@@ -97,9 +97,8 @@ class CurObj:
         :return:
         """
         if self.__chain_lock.locked():
-            from threading import ThreadError
             self.__chain_lock.release()
-            raise ThreadError('链式调用未完结')
+            logger.warn('链式调用未完结,释放调用锁')
         setattr(self, '__chain_action_flag', True)
         setattr(self, '__chain_result', {})
         self.__chain_lock.acquire()
@@ -168,7 +167,7 @@ class CurObj:
                 if self._poolFlag:
                     # 连接池
                     self._conn = self._pool.get_conn()
-                    self._db = self._conn.get_connect()
+                    self._db = self._conn._con._con
                 else:
                     # 单个连接理论上只执行一次,过后直接关闭
                     self._db = Connection()
@@ -401,14 +400,13 @@ class CurObj:
                 _sql = self.get_sql(methodName=methodName, args=args, pageInfo=None)
         except Exception as ex:
             logger.error(ex)
-            return result
-        finally:
             # 关闭连接
             self.close()
             # 调试模式语句执行信息打印
             if self._debug:
                 print_debug(methodName=methodName, args=args, sql=_sql, result=result)
             self.lock.release()
+            return result
         try:
             # 试执行语句
             self._cursor.execute(_sql)
